        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>14</strong> miembros: 13 <br>4,7,10,14,15,17,18,21,22,23,31,47,48';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 12 <br>3,8,13,16,20,26,30,34,35,41,45,50';}
       if(rr==7 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>12</strong> miembros: 10 <br>1,2,9,11,12,24,25,39,42,46';}
       if(rr==7 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>38</strong> miembros: 9 <strong>control</strong><br>0,6,27,28,29,36,38,40,43';}
       if(rr==7 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>49</strong> miembros: 7 <br>5,19,32,33,37,44,49';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>14</strong> miembros: 13 <br>4,7,10,14,15,17,18,21,22,23,31,47,48';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 12 <br>3,8,13,16,20,26,30,34,35,41,45,50';}
       if(rr==34 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>12</strong> miembros: 10 <br>1,2,9,11,12,24,25,39,42,46';}
       if(rr==34 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>38</strong> miembros: 9 <strong>control</strong><br>0,6,27,28,29,36,38,40,43';}
       if(rr==34 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>49</strong> miembros: 7 <br>5,19,32,33,37,44,49';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>14</strong> miembros: 13 <br>4,7,10,14,15,17,18,21,22,23,31,47,48';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 12 <br>3,8,13,16,20,26,30,34,35,41,45,50';}
       if(rr==35 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>12</strong> miembros: 10 <br>1,2,9,11,12,24,25,39,42,46';}
       if(rr==35 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>38</strong> miembros: 9 <strong>control</strong><br>0,6,27,28,29,36,38,40,43';}
       if(rr==35 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>49</strong> miembros: 7 <br>5,19,32,33,37,44,49';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>14</strong> miembros: 13 <br>4,7,10,14,15,17,18,21,22,23,31,47,48';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 12 <br>3,8,13,16,20,26,30,34,35,41,45,50';}
       if(rr==36 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>12</strong> miembros: 10 <br>1,2,9,11,12,24,25,39,42,46';}
       if(rr==36 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>38</strong> miembros: 9 <strong>control</strong><br>0,6,27,28,29,36,38,40,43';}
       if(rr==36 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>49</strong> miembros: 7 <br>5,19,32,33,37,44,49';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>14</strong> miembros: 13 <br>4,7,10,14,15,17,18,21,22,23,31,47,48';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 12 <br>3,8,13,16,20,26,30,34,35,41,45,50';}
       if(rr==37 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>12</strong> miembros: 10 <br>1,2,9,11,12,24,25,39,42,46';}
       if(rr==37 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>38</strong> miembros: 9 <strong>control</strong><br>0,6,27,28,29,36,38,40,43';}
       if(rr==37 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>49</strong> miembros: 7 <br>5,19,32,33,37,44,49';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>14</strong> miembros: 13 <br>4,7,10,14,15,17,18,21,22,23,31,47,48';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 12 <br>3,8,13,16,20,26,30,34,35,41,45,50';}
       if(rr==38 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>12</strong> miembros: 10 <br>1,2,9,11,12,24,25,39,42,46';}
       if(rr==38 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>38</strong> miembros: 9 <strong>control</strong><br>0,6,27,28,29,36,38,40,43';}
       if(rr==38 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>49</strong> miembros: 7 <br>5,19,32,33,37,44,49';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>14</strong> miembros: 13 <br>4,7,10,14,15,17,18,21,22,23,31,47,48';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>41</strong> miembros: 12 <br>3,8,13,16,20,26,30,34,35,41,45,50';}
       if(rr==39 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>12</strong> miembros: 10 <br>1,2,9,11,12,24,25,39,42,46';}
       if(rr==39 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>4</strong> representante: <strong>38</strong> miembros: 9 <strong>control</strong><br>0,6,27,28,29,36,38,40,43';}
       if(rr==39 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260623 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>5</strong> representante: <strong>49</strong> miembros: 7 <br>5,19,32,33,37,44,49';}
}
